==> vrealize_6_ansible-0.0.164.tar.gz: vrealize_6_ansible-0.0.164/vrealize_6_ansible/vracatalog.py <==
#!/usr/bin/python
__author__ = 'Piotr Matuszczyk <piotr.matuszczyk@sap.com>'

import json

class Vracatalog:
  resourcename = None
  resourceids = []
  resourcedata = []
  catalogtemp = []
  
  def getCatalogResourceDataByName(self, o, name):
    url = '/catalog-service/api/consumer/entitledCatalogItems'
    o.sendGETRequest(url)
    if o.errorlist[0] == 0:
      o.errorlist = [1, 'There is no available Catalog Item with name: %s'%name]
      for i in o.response.json()['content']:
        if i['catalogItem']['name'] == name:
          for n in i['entitledOrganizations']:
            subtenantRef = n['subtenantRef']
            self.catalogtemp = [i['catalogItem']['id'], i['catalogItem']['providerBinding']['bindingId'],
                                 i['catalogItem']['providerBinding']['providerRef']['id'], i['catalogItem']['serviceRef']['id'],
                                 subtenantRef]
            o.errorlist = [0]
            break
      


  def getAllCatalogItems(self, o):
    url = '/catalog-service/api/consumer/entitledCatalogItems'
    o.sendGETRequest(url)
    if o.errorlist[0] == 0:
      for i in o.response.json()['content']:
        for n in i['entitledOrganizations']:
          subtenantRef = n['subtenantRef']
          self.catalogtemp.append({"name":i['catalogItem']['name'], "description":i['catalogItem']['description'], "id":i['catalogItem']['id'],
                                   "bindingId":i['catalogItem']['providerBinding']['bindingId'], "providerRef":i['catalogItem']['providerBinding']['providerRef']['id'],
                                   "serviceRef":i['catalogItem']['serviceRef']['id'], "subtenantRef":subtenantRef, "status":i['catalogItem']['status']})

  def findVmResourceIds(self, o1, o2):
    url = '/catalog-service/api/consumer/requests/'+o1.requestid+'/resources'
    o2.sendGETRequest(url)
    if o2.errorlist[0] == 0:
      for i in o2.response.json()['content']:
        self.resourceids.append(i['id'])
  
  def getVmResourceData(self, o):
    k = 0
    for i in self.resourceids:
      url = '/catalog-service/api/consumer/resources/'+i
      o.sendGETRequest(url)
      if o.errorlist[0] == 0:
        k += 1
        j = o.response.json()
        globals()['resourceobject{}'.format(k)] = Vraresource()
        globals()['resourceobject{}'.format(k)].unmarshalling(j)
    for i in Vraresource._registry:
      self.resourcedata.append({'hostname': i.name, 'created': i.createdate, 'ipaddress': i.network['ipaddress'], 'vmid': i.id, 'hostgroup': i.hostgroup})


from vrealize_6_ansible.vraresource import *

==> vrealize_6_ansible-0.0.205.tar.gz: vrealize_6_ansible-0.0.205/vrealize_6_ansible/vracatalog.py <==
#!/usr/bin/python
__author__ = 'Piotr Matuszczyk <piotr.matuszczyk@sap.com>'

class Vracatalog:
  def __init__(self):
    self.resourcename = None
    self.resourceids = []
    self.resourcedata = []
    self.catalogtemp = []
  
  def getCatalogResourceDataByName(self, o, name):
    url = '/catalog-service/api/consumer/entitledCatalogItems'
    o.sendGETRequest(url)
    if o.errorlist[0] == 0:
      o.errorlist = [1, 'There is no available Catalog Item with name: %s'%name]
      for i in o.response.json()['content']:
        if i['catalogItem']['name'] == name:
          for n in i['entitledOrganizations']:
            subtenantRef = n['subtenantRef']
            self.catalogtemp = [i['catalogItem']['id'], i['catalogItem']['providerBinding']['bindingId'],
                                 i['catalogItem']['providerBinding']['providerRef']['id'], i['catalogItem']['serviceRef']['id'],
                                 subtenantRef]
            o.errorlist = [0]
            break
      
  def getAllCatalogItems(self, o):
    url = '/catalog-service/api/consumer/entitledCatalogItems'
    o.sendGETRequest(url)
    if o.errorlist[0] == 0:
      for i in o.response.json()['content']:
        for n in i['entitledOrganizations']:
          subtenantRef = n['subtenantRef']
          self.catalogtemp.append({"name":i['catalogItem']['name'], "description":i['catalogItem']['description'], "id":i['catalogItem']['id'],
                                   "bindingId":i['catalogItem']['providerBinding']['bindingId'], "providerRef":i['catalogItem']['providerBinding']['providerRef']['id'],
                                   "serviceRef":i['catalogItem']['serviceRef']['id'], "subtenantRef":subtenantRef, "status":i['catalogItem']['status']})

  def findVmResourceIds(self, o1, o2):
    url = '/catalog-service/api/consumer/requests/'+o1.requestid+'/resources'
    o2.sendGETRequest(url)
    if o2.errorlist[0] == 0:
      for i in o2.response.json()['content']:
        self.resourceids.append(i['id'])
  
  def getVmResourceData(self, o, mngdomain, nameservers):
    k = 0
    for i in self.resourceids:
      o.response = None
      url = '/catalog-service/api/consumer/resources/'+i
      o.sendGETRequest(url)
      if o.errorlist[0] == 0:
        k += 1
        j = o.response.json()
        globals()[i] = Vraresource()
        globals()[i].unmarshalling(j, mngdomain, nameservers)
       
  def prepareResourceDataoutput(self):
    for i in Vraresource._registry:
      if (i.type == 'vm' and not i.tierpart['tierpart']):
        self.resourcedata.append({'hostname': i.name, 'created': i.createdate, 'ipaddress': i.network['ipaddress'], 'vmid': i.id, 'hostgroup': i.hostgroup})
      elif (i.type == 'vm' and i.tierpart['tierpart']):
        self.resourcedata.append({'hostname': i.name, 'created': i.createdate, 'internal_ipaddress': i.network['ipaddress'], 'external_ipaddress': i.network['external_ipaddress'], 'vmid': i.id, 'hostgroup': i.hostgroup})


from vrealize_6_ansible.vraresource import Vraresource
